@@ -9,6 +9,7 @@ create_job_subscription = wrapper.create_job_subscription
 create_printer_subscription = wrapper. create_printer_subscription
 cancel_job = wrapper.cancel_job
 release_job = wrapper.release_job
+create_job = wrapper.create_job
 create_printer_subscription = wrapper.create_printer_subscription
 cups_add_modify_class = wrapper.cups_add_modify_class
 cups_add_modify_printer = wrapper.cups_add_modify_printer
@@ -26,7 +27,9 @@ get_printer_attributes = wrapper.get_printer_attributes
 get_subscriptions = wrapper.get_subscriptions
 get_notifications = wrapper.get_notifications
 pause_printer = wrapper.pause_printer
+print_job = wrapper.print_job
 resume_printer = wrapper.resume_printer
+send_document = wrapper.send_document
 hold_new_jobs = wrapper.hold_new_jobs
 release_held_new_jobs = wrapper.release_held_new_jobs
 cancel_subscription = wrapper.cancel_subscription
